0.9.9 API documentation: scalar_ulp.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

scalar_ulp.hpp
Go to the documentation of this file.
1
16 #pragma once
17
18 // Dependencies
19 #include "../ext/scalar_int_sized.hpp"
20 #include "../common.hpp"
21 #include "../detail/qualifier.hpp"
22
23 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
24 # pragma message("GLM: GLM_EXT_scalar_ulp extension included")
25 #endif
26
27 namespace glm
28 {
34 template<typename genType>
35 GLM_FUNC_DECL genType nextFloat(genType x);
36
42 template<typename genType>
43 GLM_FUNC_DECL genType prevFloat(genType x);
44
50 template<typename genType>
51 GLM_FUNC_DECL genType nextFloat(genType x, int ULPs);
52
58 template<typename genType>
59 GLM_FUNC_DECL genType prevFloat(genType x, int ULPs);
60
64 GLM_FUNC_DECL int floatDistance(float x, float y);
65
69 GLM_FUNC_DECL int64 floatDistance(double x, double y);
70
72 }//namespace glm
73
74 #include "scalar_ulp.inl"
glm::int64
detail::int64 int64
64 bit signed integer type.
Definition: scalar_int_sized.hpp:67
glm
Definition: common.hpp:20